@@ -3,7 +3,12 @@ package Protocol::WebSocket;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
+
+use Protocol::WebSocket::Frame;
+use Protocol::WebSocket::Handshake::Client;
+use Protocol::WebSocket::Handshake::Server;
+use Protocol::WebSocket::URL;
 
 1;
 __END__
